-------------------------------------------------------------------------------
-- Title      : firUnit
-- Project    : 
-------------------------------------------------------------------------------
-- File       : operativeUnit.vhd
-- Author     : Jean-Noel BAZIN  <jnbazin@pc-disi-026.enst-bretagne.fr>
-- Company    : 
-- Created    : 2018-04-11
-- Last update: 2018-04-11
-- Platform   : 
-- Standard   : VHDL'93/02
-------------------------------------------------------------------------------
-- Description: 8 bit FIR
-------------------------------------------------------------------------------
-- Copyright (c) 2018 
-------------------------------------------------------------------------------
-- Revisions  :
-- Date        Version  Author  Description
-- 2018-04-11  1.0      jnbazin Created
-------------------------------------------------------------------------------

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;

entity firUnit is

  port (
    I_clock               : in  std_logic;  -- global clock
    I_reset               : in  std_logic;  -- asynchronous global reset
    I_inputSample         : in  std_logic_vector(7 downto 0);  -- 8 bit input sample
    I_inputSampleValid    : in  std_logic;
    O_filteredSample      : out std_logic_vector(7 downto 0);  -- filtered sample
    O_filteredSampleValid : out std_logic

    );

end entity firUnit;

architecture archi_firUnit of firUnit is

  component controlUnit is
    port (
      I_clock               : in  std_logic;
      I_reset               : in  std_logic;
      I_inputSampleValid    : in  std_logic;
      I_processingDone      : in  std_logic;
      O_loadShift           : out std_logic;
      O_initAddress         : out std_logic;
      O_incrAddress         : out std_logic;
      O_initSum             : out std_logic;
      O_loadSum             : out std_logic;
      O_FilteredSampleValid : out std_logic;
      O_loadOutA            : out std_logic;
      O_loadOutBaseline     : out std_logic;
      O_loadOutLissage       : out std_logic;
      O_SelFiltre           : out std_logic_vector(1 downto 0 );
      I_processingDoneIRRA  : in  std_logic;
      I_processingDoneIRRB  : in  std_logic;
      I_processingDoneBaseline : in  std_logic;
      I_processingDoneLissage : in  std_logic);
  end component controlUnit;

  component operativeUnit is
    port (
      I_clock          : in  std_logic;
      I_reset          : in  std_logic;
      I_inputSample    : in  std_logic_vector(7 downto 0);
      I_loadShift      : in  std_logic;
      I_initAddress    : in  std_logic;
      I_incrAddress    : in  std_logic;
      I_initSum        : in  std_logic;
      I_loadSum        : in  std_logic;
      I_loadOutA        : in  std_logic;  
      I_loadOutBaseLine : in  std_logic;   
      I_loadOutLissage  : in  std_logic;
      I_SelFiltre       : out std_logic_vector(1 downto 0 );
      O_processingDoneA : out std_logic;  
      O_processingDoneB : out std_logic;   
      O_processingDoneBaseLine: out std_logic;  
      O_processingDoneLissage : out std_logic);
  end component operativeUnit;

  signal SC_processingDone : std_logic;
  signal SC_loadShift      : std_logic;
  signal SC_initAddress    : std_logic;
  signal SC_incrAddress    : std_logic;
  signal SC_initSum        : std_logic;
  signal SC_loadSum        : std_logic;
  signal SC_loadY          : std_logic;
  signal SC_loadOutA       : std_logic;
  signal SC_loadOutBaseLine: std_logic;
  signal SC_loadOutLissage : std_logic;
  signal SC_sel            : std_logic_vector(1 downto 0);
  signal SC_processingDoneA : std_logic;
  signal SC_processingDoneB : std_logic;
  signal SC_processingDoneBaseLine: std_logic;
  signal SC_processingDoneLissage : std_logic;

begin

  controlUnit_1 : entity work.controlUnit
    port map (
      I_clock               => I_clock,
      I_reset               => I_reset,
      I_inputSampleValid    => I_inputSampleValid,
      O_loadShift           => SC_loadShift,
      O_initAddress         => SC_initAddress,
      O_incrAddress         => SC_incrAddress,
      O_initSum             => SC_initSum,
      O_loadSum             => SC_loadSum,
      O_loadOutA            => SC_loadOutA,
      O_loadOutBaseLine     => SC_loadOutBaseLine,
      O_loadOutLissage      => SC_loadOutLissage,
      O_selFiltre                => SC_sel,
      I_processingDoneIRRA  => SC_processingDoneA,
      I_processingDoneIRRB => SC_processingDoneB,
      I_processingDoneBaseline => SC_processingDoneBaseLine,
      I_processingDoneLissage => SC_processingDoneLissage,
      O_FilteredSampleValid => O_FilteredSampleValid);

  operativeUnit_1 : entity work.operativeUnit
    port map (
      I_clock          => I_clock,
      I_reset          => I_reset,
      I_inputSample    => I_inputSample,
      I_loadShift      => SC_loadShift,
      I_initAddress    => SC_initAddress,
      I_incrAddress    => SC_incrAddress,
      I_initSum        => SC_initSum,
      I_loadSum        => SC_loadSum,
      I_loadOutA          => SC_loadOutA,
      I_loadOutBaseLine   => SC_loadOutBaseLine,
      I_loadOutLissage    => SC_loadOutLissage,
      O_processingDoneA => SC_processingDoneA,
      O_processingDoneB => SC_processingDoneB,
      O_processingDoneBaseLine => SC_processingDoneBaseLine,
      O_processingDoneLissage => SC_processingDoneLissage,
      I_selFiltre            => SC_sel,
      O_total              => O_filteredSample  );

end architecture archi_firUnit;
